@@ -178,19 +178,26 @@ ui <- tagList(
                                                                "LPC" = "LPC",
                                                                "LPE" = "LPE",
                                                                "PC" = "PC",
+                                                               "PCo" = "PCo",
+                                                               "PCp" = "PCp",
                                                                "PE" = "PE",
+                                                               "PEo" = "PEo",
+                                                               "PEp" = "PEp",
                                                                "PG" = "PG",
+                                                               "PI" = "PI",
                                                                "Sphingoid bases" = "Sph",
                                                                "Sphingoid bases phosphate" = "SphP",
                                                                "Cer" = "Cer",
+                                                               "AcylCer" = "AcylCer",
+                                                               "CerP" = "CerP",
                                                                "SM" = "SM",
                                                                "Carnitines" = "Carnitines",
                                                                "CE" = "CE",
                                                                "DG" = "DG",
                                                                "TG" = "TG"),
-                                                             selected = c("MG", "LPC", "LPE", "PC", "PE", "PG", "Sph",
-                                                                          "SphP", "Cer", "SM", "Carnitines", "CE", "DG", "TG"))),
-                                column(6, checkboxGroupInput("lipidClassesNeg", "Lipid classes to annotate for ESI+ :",
+                                                             selected = c("MG", "LPC", "LPE", "PC", "PCo", "PCp", "PE", "PEo", "PEp", "PG", "PI", "Sph",
+                                                                          "SphP", "Cer", "AcylCer", "CerP", "SM", "Carnitines", "CE", "DG", "TG"))),
+                                column(6, checkboxGroupInput("lipidClassesNeg", "Lipid classes to annotate for ESI- :",
                                                              c("FA" = "FA",
                                                                "FAHFA" = "FAHFA",
                                                                "LPC" = "LPC",
@@ -199,18 +206,25 @@ ui <- tagList(
                                                                "LPI" = "LPI",
                                                                "LPS" = "LPS",
                                                                "PC" = "PC",
+                                                               "PCo" = "PCo",
+                                                               "PCp" = "PCp",
                                                                "PE" = "PE",
+                                                               "PEo" = "PEo",
+                                                               "PEp" = "PEp",
                                                                "PG" = "PG",
                                                                "PI" = "PI",
                                                                "PS" = "PS",
                                                                "Sphingoid bases" = "Sph",
                                                                "Sphingoid bases phosphate" = "SphP",
                                                                "Cer" = "Cer",
+                                                               "AcylCer" = "AcylCer",
+                                                               "CerP" = "CerP",
+                                                               "SM" = "SM",
                                                                "CL" = "CL",
                                                                "Bile Acids" = "BA"),
-                                                             selected = c("FA", "FAHFA", "LPC", "LPE", "LPG", "LPI",
-                                                                          "LPS", "PC", "PE", "PG", "PI", "PS", "Sph",
-                                                                          "SphP", "Cer", "CL", "BA")))),
+                                                             selected = c("FA", "FAHFA", "LPC", "LPE", "LPG", "LPI", "LPS", 
+                                                                          "PC", "PCo", "PCp", "PE", "PEo", "PEp", "PG", "PI", "PS", 
+                                                                          "Sph", "SphP", "Cer", "AcylCer", "CerP", "SM", "CL", "BA")))),
                        tags$hr(),
                        fluidRow(actionButton("GoBackTo3", "< Previous", width = "100px", 
                                              style="margin:40px 0px"), 
